@@ -28,11 +28,11 @@
 #include <QProcess>
 #include <QTranslator>
 
-#include <unistd.h>
 #include "mainwindow.h"
 #include "version.h"
+#include <unistd.h>
 
-QString starting_home = qEnvironmentVariable("HOME");
+const extern QString starting_home = qEnvironmentVariable("HOME");
 
 int main(int argc, char *argv[])
 {
@@ -49,20 +49,20 @@ int main(int argc, char *argv[])
     parser.process(app);
 
     QTranslator qtTran;
-    if (qtTran.load(QLocale::system(), QStringLiteral("qt_"), QLibraryInfo::location(QLibraryInfo::TranslationsPath)))
+    if (qtTran.load(QLocale(), QStringLiteral("qt"), QStringLiteral("_"), QLibraryInfo::location(QLibraryInfo::TranslationsPath)))
         app.installTranslator(&qtTran);
 
     QTranslator qtBaseTran;
-    if (qtBaseTran.load("qtbase_" + QLocale::system().name(), QLibraryInfo::location(QLibraryInfo::TranslationsPath)))
+    if (qtBaseTran.load("qtbase_" + QLocale().name(), QLibraryInfo::location(QLibraryInfo::TranslationsPath)))
         app.installTranslator(&qtBaseTran);
 
     QTranslator appTran;
-    if (appTran.load(app.applicationName() + "_" + QLocale::system().name(), "/usr/share/" + app.applicationName() + "/locale"))
+    if (appTran.load(app.applicationName() + "_" + QLocale().name(), "/usr/share/" + app.applicationName() + "/locale"))
         app.installTranslator(&appTran);
 
     // root guard
 
-    if (QProcess::execute("/bin/bash", {"-c", "logname |grep -q ^root$"}) == 0) {
+    if (QProcess::execute(QStringLiteral("/bin/bash"), {"-c", "logname |grep -q ^root$"}) == 0) {
         QMessageBox::critical(nullptr, QObject::tr("Error"),
                               QObject::tr("You seem to be logged in as root, please log out and log in as normal user to use this program."));
         exit(EXIT_FAILURE);
@@ -73,6 +73,6 @@ int main(int argc, char *argv[])
         w.show();
         return app.exec();
     } else {
-        QProcess::startDetached("/usr/bin/mxbo-launcher", {});
+        QProcess::startDetached(QStringLiteral("/usr/bin/mxbo-launcher"), {});
     }
 }
