@@ -1,22 +1,20 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="pt_BR">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
 <context>
     <name>CustomDialog</name>
     <message>
-        <location filename="../dialog.cpp" line="15"/>
+        <location filename="dialog.cpp" line="15"/>
         <source>Live environment detected. Please select the root partition of the
  system you want to modify (only Linux partitions are displayed)</source>
-        <translation>Ambiente USB-Executável detectado. Por favor selecione a partição root do
-sistema que você quer modificar (apenas partições Linux serão mostradas)</translation>
+        <translation>Ambiente USB Executável detectado. Por favor selecione a partição raiz (root) do
+sistema que você deseja modificar (apenas partições Linux serão exibidas)</translation>
     </message>
     <message>
-        <location filename="../dialog.cpp" line="22"/>
+        <location filename="dialog.cpp" line="22"/>
         <source>OK</source>
         <translation>Aceitar</translation>
     </message>
     <message>
-        <location filename="../dialog.cpp" line="23"/>
+        <location filename="dialog.cpp" line="23"/>
         <source>Cancel</source>
         <translation>Cancelar</translation>
     </message>
@@ -24,339 +22,339 @@ sistema que você quer modificar (apenas partições Linux serão mostradas)</tr
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../mainwindow.ui" line="32"/>
+        <location filename="mainwindow.ui" line="32"/>
         <source>Options</source>
         <translation>Opções</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="38"/>
+        <location filename="mainwindow.ui" line="38"/>
         <source>Kernel parameters</source>
         <translation>Parâmetros do Núcleo (Kernel)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="58"/>
+        <location filename="mainwindow.ui" line="58"/>
         <source>Set to &apos;0&apos; to boot immediately without displaying the menu, or to &apos;-1&apos; to wait indefinitely</source>
         <translation>Ajuste para &quot;0&quot; para iniciar imediatamente sem mostrar o menu, ou, para &quot;-1&quot; para aguardar indefinidamente</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="61"/>
+        <location filename="mainwindow.ui" line="61"/>
         <source>Menu timeout</source>
         <translation>Tempo de espera do menu</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="74"/>
+        <location filename="mainwindow.ui" line="74"/>
         <source>Boot to</source>
         <translation>Iniciar para</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="81"/>
+        <location filename="mainwindow.ui" line="81"/>
         <source>Use simplified menu structure without submenus</source>
-        <translation>Usar menu de estrutura simplificada sem submenus</translation>
+        <translation>Usar uma de estrutura de menu simplificada sem submenus</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="84"/>
+        <location filename="mainwindow.ui" line="84"/>
         <source>Use flat menus (no submenus)</source>
         <translation>Usar menus condensados (sem submenus)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="113"/>
+        <location filename="mainwindow.ui" line="113"/>
         <source>seconds</source>
         <translation>segundos</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="120"/>
+        <location filename="mainwindow.ui" line="120"/>
         <source>With this option enabled whatever entry you select from the grub boot menu will be saved as the new default for future boots</source>
-        <translation>Com essa opção habilitada qualquer entrada que você selecionar do menu de inicialização do grub será o novo padrão para inicializações futuras</translation>
+        <translation>Com essa opção habilitada qualquer entrada que você selecionar no menu de inicialização do grub será salva como o novo padrão para inicializações futuras</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="123"/>
+        <location filename="mainwindow.ui" line="123"/>
         <source>Enable saving last boot choice</source>
-        <translation>Habilita salvamento da última escolha de inicialização</translation>
+        <translation>Habilita o salvamento da última escolha de inicialização</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="136"/>
+        <location filename="mainwindow.ui" line="136"/>
         <source>Background</source>
         <translation>Tela de fundo</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="154"/>
+        <location filename="mainwindow.ui" line="154"/>
         <source>Image</source>
         <translation>Imagem</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="167"/>
-        <location filename="../mainwindow.ui" line="269"/>
+        <location filename="mainwindow.ui" line="167"/>
+        <location filename="mainwindow.ui" line="269"/>
         <source>Enable theme</source>
         <translation>Habilitar tema</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="247"/>
+        <location filename="mainwindow.ui" line="247"/>
         <source>Splash</source>
         <translation>Tela de início</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="282"/>
+        <location filename="mainwindow.ui" line="282"/>
         <source>Preview</source>
         <translation>Pré-visualização</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="305"/>
+        <location filename="mainwindow.ui" line="305"/>
         <source>Messages</source>
         <translation>Mensagens</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="311"/>
+        <location filename="mainwindow.ui" line="311"/>
         <source>Very detailed</source>
         <translation>Bem detalhado</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="318"/>
+        <location filename="mainwindow.ui" line="318"/>
         <source>Detailed (default setting)</source>
         <translation>Detalhado (ajuste padrão)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="328"/>
+        <location filename="mainwindow.ui" line="328"/>
         <source>Limited</source>
         <translation>Limitado</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="344"/>
+        <location filename="mainwindow.ui" line="344"/>
         <source>Display log</source>
         <translation>Exibir o relatório</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="397"/>
+        <location filename="mainwindow.ui" line="397"/>
         <source>Display help </source>
-        <translation>Exibir a ajuda</translation>
+        <translation>Exibir ajuda</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="400"/>
+        <location filename="mainwindow.ui" line="400"/>
         <source>Help</source>
         <translation>Ajuda</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="407"/>
+        <location filename="mainwindow.ui" line="407"/>
         <source>Alt+H</source>
         <translation>Alt+H</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="439"/>
+        <location filename="mainwindow.ui" line="439"/>
         <source>About this application</source>
-        <translation>Sobre esta aplicação</translation>
+        <translation>Sobre este aplicativo</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="442"/>
+        <location filename="mainwindow.ui" line="442"/>
         <source>About...</source>
         <translation>Sobre...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="449"/>
+        <location filename="mainwindow.ui" line="449"/>
         <source>Alt+B</source>
         <translation>Alt+B</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="484"/>
+        <location filename="mainwindow.ui" line="484"/>
         <source>Quit application</source>
-        <translation>Sair da aplicação</translation>
+        <translation>Sair do aplicativo</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="487"/>
-        <location filename="../mainwindow.cpp" line="692"/>
+        <location filename="mainwindow.ui" line="487"/>
+        <location filename="mainwindow.cpp" line="665"/>
         <source>Close</source>
         <translation>Fechar</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="494"/>
+        <location filename="mainwindow.ui" line="494"/>
         <source>Alt+N</source>
         <translation>Alt+N</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="535"/>
+        <location filename="mainwindow.ui" line="535"/>
         <source>Apply</source>
         <translation>Aplicar</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="67"/>
+        <location filename="mainwindow.cpp" line="66"/>
         <source>Still running</source>
-        <translation>Ainda rodando</translation>
+        <translation>Ainda executando</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="67"/>
+        <location filename="mainwindow.cpp" line="66"/>
         <source>Process still running. Are you sure you want to quit?</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="168"/>
+        <location filename="mainwindow.cpp" line="163"/>
         <source>Installing bootsplash, please wait</source>
-        <translation>Instalando tela de inicialização, favor aguardar</translation>
+        <translation>Instalando a tela de inicialização, por favor aguarde</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="175"/>
+        <location filename="mainwindow.cpp" line="170"/>
         <source>Updating sources</source>
         <translation>Atualizando fontes</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="177"/>
+        <location filename="mainwindow.cpp" line="172"/>
         <source>Installing</source>
         <translation>Instalando</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="181"/>
-        <location filename="../mainwindow.cpp" line="327"/>
+        <location filename="mainwindow.cpp" line="176"/>
+        <location filename="mainwindow.cpp" line="318"/>
         <source>Error</source>
         <translation>Erro</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="181"/>
+        <location filename="mainwindow.cpp" line="176"/>
         <source>Could not install the bootsplash.</source>
-        <translation>Não pôde instalar a tela de inicialização</translation>
+        <translation>Não foi possível instalar a tela de inicialização</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="283"/>
-        <location filename="../mainwindow.cpp" line="333"/>
+        <location filename="mainwindow.cpp" line="274"/>
+        <location filename="mainwindow.cpp" line="324"/>
         <source>Cannot continue</source>
         <translation>Não pode continuar</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="283"/>
+        <location filename="mainwindow.cpp" line="274"/>
         <source>Nothing was selected, cannot change boot options. Exiting...</source>
-        <translation>Nada foi selecionado, não pode mudar opções de inicialização. Saindo...</translation>
+        <translation>Nada foi selecionado, não é possível alterar as opções de inicialização. Saindo...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="328"/>
+        <location filename="mainwindow.cpp" line="319"/>
         <source>Could not create a temporary folder</source>
-        <translation type="unfinished"></translation>
+        <translation>Não foi possível criar uma pasta temporária</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="333"/>
+        <location filename="mainwindow.cpp" line="324"/>
         <source>Cannot create chroot environment, cannot change boot options. Exiting...</source>
-        <translation>Não pode criar ambiente chroot, não pode mudar opções de inicialização. Saindo...</translation>
+        <translation>Não é possível criar ambiente chroot, não é possível alterar as opções de inicialização. Saindo ...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="582"/>
-        <location filename="../mainwindow.cpp" line="896"/>
+        <location filename="mainwindow.cpp" line="561"/>
+        <location filename="mainwindow.cpp" line="857"/>
         <source>Updating configuration, please wait</source>
-        <translation>Atualizando configuração, favor aguardar</translation>
+        <translation>Atualizando a configuração, por favor aguarde</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="633"/>
+        <location filename="mainwindow.cpp" line="608"/>
         <source>Updating initramfs...</source>
         <translation>Atualizando initramfs...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="643"/>
-        <location filename="../mainwindow.cpp" line="909"/>
+        <location filename="mainwindow.cpp" line="617"/>
+        <location filename="mainwindow.cpp" line="869"/>
         <source>Updating grub...</source>
         <translation>Atualizando grub...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="647"/>
+        <location filename="mainwindow.cpp" line="621"/>
         <source>Done</source>
         <translation>Feito</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="647"/>
+        <location filename="mainwindow.cpp" line="621"/>
         <source>Changes have been successfully applied.</source>
-        <translation>Mudanças têm sido aplicadas com sucesso</translation>
+        <translation>As alterações foram aplicadas com sucesso.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="660"/>
+        <location filename="mainwindow.cpp" line="634"/>
         <source>About</source>
         <translation>Sobre</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="661"/>
+        <location filename="mainwindow.cpp" line="635"/>
         <source>Version: </source>
         <translation>Versão: </translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="662"/>
+        <location filename="mainwindow.cpp" line="636"/>
         <source>Program for selecting common start-up choices</source>
-        <translation>Programa para selecionar escolhas comuns de inicialização</translation>
+        <translation>Programa para selecionar opções de inicialização comuns</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="664"/>
+        <location filename="mainwindow.cpp" line="638"/>
         <source>Copyright (c) MX Linux</source>
         <translation>Direitos de Autor (c) MX Linux</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="665"/>
-        <location filename="../mainwindow.cpp" line="675"/>
+        <location filename="mainwindow.cpp" line="639"/>
+        <location filename="mainwindow.cpp" line="649"/>
         <source>License</source>
         <translation>Licença</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="666"/>
-        <location filename="../mainwindow.cpp" line="681"/>
+        <location filename="mainwindow.cpp" line="640"/>
+        <location filename="mainwindow.cpp" line="654"/>
         <source>Changelog</source>
         <translation>Relatório de alterações</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="667"/>
+        <location filename="mainwindow.cpp" line="641"/>
         <source>Cancel</source>
         <translation>Cancelar</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="711"/>
+        <location filename="mainwindow.cpp" line="684"/>
         <source>MX Boot Options</source>
         <translation>MX Opções de Inicialização</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="723"/>
+        <location filename="mainwindow.cpp" line="695"/>
         <source>Running in a Virtual Machine</source>
-        <translation>Rodando em uma Máquina Virtual</translation>
+        <translation>Executando em uma Máquina Virtual</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="724"/>
+        <location filename="mainwindow.cpp" line="696"/>
         <source>You current system is running in a Virtual Machine,
 Plymouth bootsplash will work in a limited way, you also won&apos;t be able to preview the theme</source>
-        <translation>Seu sistema atual está rodando numa Máquina Virtual,
-a tela do Plymouth irá trabalhar numa maneira limitada, você também não poderá pré-visualizar o tema.</translation>
+        <translation>Seu sistema atual está sendo executado em uma Máquina Virtual,
+a tela do Plymouth funcionará de forma limitada, você também não poderá visualizar o tema.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="729"/>
+        <location filename="mainwindow.cpp" line="701"/>
         <source>Plymouth packages not installed</source>
         <translation>Pacotes do Plymouth não instalados</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="729"/>
+        <location filename="mainwindow.cpp" line="701"/>
         <source>Plymouth packages are not currently installed.
 OK to go ahead and install them?</source>
-        <translation>Pacotes do Plymouth atualmente não instalados.
+        <translation>Os pacotes do Plymouth atualmente não estão instalados.
 Quer prosseguir e instalá-los?</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="750"/>
+        <location filename="mainwindow.cpp" line="721"/>
         <source>Images (*.png *.jpg *.jpeg *.tga)</source>
         <translation>Imagens (*.png *.jpg *.jpeg *.tga)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="859"/>
+        <location filename="mainwindow.cpp" line="823"/>
         <source>Press any key to close</source>
         <translation>Pressione qualquer tecla para fechar</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="861"/>
+        <location filename="mainwindow.cpp" line="825"/>
         <source>Log not found</source>
         <translation>Relatório não encontrado</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="861"/>
+        <location filename="mainwindow.cpp" line="825"/>
         <source>Could not find log at </source>
         <translation>Não pude encontrar relatório em</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="875"/>
+        <location filename="mainwindow.cpp" line="838"/>
         <source>Needs reboot</source>
         <translation>Precisa reiniciar</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="875"/>
+        <location filename="mainwindow.cpp" line="838"/>
         <source>Plymouth was just installed, you might need to reboot before being able to display previews</source>
-        <translation>Plymouth acabou de ser instalado, você deveria reiniciar antes para poder exibir as pré-visualizações </translation>
+        <translation>Plymouth acabou de ser instalado,  pode ser necessário reiniciar antes de poder exibir as visualizações </translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="931"/>
+        <location filename="mainwindow.cpp" line="891"/>
         <source>Click to select theme</source>
         <translation>Clique para selecionar o tema</translation>
     </message>
@@ -364,26 +362,32 @@ Quer prosseguir e instalá-los?</translation>
 <context>
     <name>QApplication</name>
     <message>
-        <source>You must run this program as root.</source>
-        <translation type="vanished">Você deve executar este programa como root.</translation>
-    </message>
-    <message>
-        <location filename="../main.cpp" line="42"/>
+        <location filename="main.cpp" line="42"/>
         <source>Program for selecting common start-up choices</source>
-        <translation type="unfinished">Programa para selecionar escolhas comuns de inicialização</translation>
+        <translation>Programa para selecionar opções de inicialização comuns</translation>
     </message>
 </context>
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../mainwindow.cpp" line="749"/>
-        <source>Select image to display in bootloader</source>
-        <translation>Selecione imagem para exibir no carregador de inicialização</translation>
+        <location filename="main.cpp" line="61"/>
+        <source>Error</source>
+        <translation>Erro</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="941"/>
+        <location filename="main.cpp" line="62"/>
+        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
+        <translation>Parece que você está conectado como root, por favor saia da sessão e entre novamente como usuário normal para usar este programa.</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="720"/>
+        <source>Select image to display in bootloader</source>
+        <translation>Selecione imagem para exibir no carregador de inicialização (bootloader)</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="901"/>
         <source>Select GRUB theme</source>
         <translation>Selecione o tema do GRUB</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
